@@ -44,10 +44,12 @@ OC.L10N.register(
     "Error" : "შეცდომა",
     "Blocked" : "დაბლოკილია",
     "Expired" : "გაუქმდა",
+    "Never" : "არასდროს",
     "Language" : "ენა",
     "Country" : "ქვეყანა",
     "Status" : "სტატუსი",
     "Created at" : "შეიქმნა",
+    "Yes" : "დიახ",
     "Validate SSL certificate" : "SSL სერტიფიკატის ვალიდაცია",
     "Shared secret" : "გაზიარებული საიდუმლო",
     "STUN servers" : "STUN სერვერები",
@@ -82,7 +84,6 @@ OC.L10N.register(
     "Choose" : "აირჩიეთ",
     "Restricted" : "აკრძალული",
     "Personal" : "პირადი",
-    "Yes" : "დიახ",
     "Password protection" : "პაროლით თავდაცვა",
     "Set a password" : "პაროლის დაყენება",
     "Edit" : "შეცვლა",
@@ -105,10 +106,6 @@ OC.L10N.register(
     "Translate" : "გადათარგმნეთ",
     "Dismiss" : "დათხოვნა",
     "Contact" : "კონტაქტი",
-    "Today" : "დღეს",
-    "Yesterday" : "გუშინ",
-    "_%n day ago_::_%n days ago_" : ["%n დღის წინ","%n დღის წინ"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Create new poll" : "ახალი გამოკითხვის შექმნა",
     "Send" : "გაგზავნა",
     "Create poll" : "გამოკითხვის შექმნა",
@@ -125,17 +122,14 @@ OC.L10N.register(
     "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
     "Search" : "ძიება",
     "More actions" : "მეტი ქმედება",
-    "Default" : "საწყისი",
     "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
     "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
     "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
-    "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი.",
     "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
     "Show your screen" : "თქვენი ეკრანის ჩვენება",
     "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
     "Submit" : "გაგზავნა",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "User" : "მომხმარებელი",
     "Password" : "პაროლი",
     "API token" : "API ტოკენი",
@@ -145,6 +139,7 @@ OC.L10N.register(
     "Polls" : "გამოკითხვები",
     "Audio" : "აუდიო",
     "Other" : "სხვა",
+    "Default" : "საწყისი",
     "Group" : "ჯგუფი",
     "Please reload the page." : "გთხოვთ გადატვირთოთ გვერდი.",
     "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
@@ -158,6 +153,12 @@ OC.L10N.register(
     "__language_name__" : "ქართული",
     "Tasks" : "დავალებები",
     "Notes" : "ჩანაწერები",
-    "Close" : "დახურვა"
+    "Today" : "დღეს",
+    "Yesterday" : "გუშინ",
+    "_%n day ago_::_%n days ago_" : ["%n დღის წინ","%n დღის წინ"],
+    "Close" : "დახურვა",
+    "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
+    "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი."
 },
 "nplurals=2; plural=(n!=1);");
