@@ -73,10 +73,10 @@ class Listener implements IEventListener {
 		$numGuests += $this->participantService->getActorsCountByType($room, Attendee::ACTOR_EMAILS, $activeSince->getTimestamp());
 
 		$message = 'call_ended';
-		if ($event instanceof CallEndedForEveryoneEvent) {
-			$message = 'call_ended_everyone';
-		} elseif (($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) && \count($userIds) === 1) {
+		if (($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) && \count($userIds) === 1) {
 			$message = 'call_missed';
+		} elseif ($event instanceof CallEndedForEveryoneEvent) {
+			$message = 'call_ended_everyone';
 		}
 
 		if ($actor instanceof Participant) {
@@ -86,7 +86,7 @@ class Listener implements IEventListener {
 			$actorType = Attendee::ACTOR_GUESTS;
 			$actorId = Attendee::ACTOR_ID_SYSTEM;
 		}
-		$this->chatManager->addSystemMessage($room, $actorType, $actorId, json_encode([
+		$this->chatManager->addSystemMessage($room, $actor, $actorType, $actorId, json_encode([
 			'message' => $message,
 			'parameters' => [
 				'users' => $userIds,
