@@ -2,43 +2,24 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2023 Joas Schilling <coding@schilljs.com>
- * @copyright Copyright (c) 2022 Informatyka Boguslawski sp. z o.o. sp.k., http://www.ib.pl/
- *
- * @author Joachim Bauch <mail@joachim-bauch.de>
- * @author Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\AppInfo;
 
 use OCA\Circles\Events\AddingCircleMemberEvent;
 use OCA\Circles\Events\CircleDestroyedEvent;
+use OCA\Circles\Events\CircleEditedEvent;
+use OCA\Circles\Events\EditingCircleEvent;
 use OCA\Circles\Events\RemovingCircleMemberEvent;
 use OCA\Files\Event\LoadSidebar;
 use OCA\Files_Sharing\Event\BeforeTemplateRenderedEvent;
 use OCA\Talk\Activity\Listener as ActivityListener;
 use OCA\Talk\Capabilities;
 use OCA\Talk\Chat\Changelog\Listener as ChangelogListener;
-use OCA\Talk\Chat\Command\Listener as CommandListener;
 use OCA\Talk\Chat\Listener as ChatListener;
 use OCA\Talk\Chat\Parser\Changelog;
-use OCA\Talk\Chat\Parser\Command;
 use OCA\Talk\Chat\Parser\ReactionParser;
 use OCA\Talk\Chat\Parser\SystemMessage;
 use OCA\Talk\Chat\Parser\UserMention;
@@ -56,19 +37,23 @@ use OCA\Talk\Events\AttendeesAddedEvent;
 use OCA\Talk\Events\AttendeesRemovedEvent;
 use OCA\Talk\Events\BeforeAttendeeRemovedEvent;
 use OCA\Talk\Events\BeforeAttendeesAddedEvent;
-use OCA\Talk\Events\BeforeCallEndedForEveryoneEvent;
-use OCA\Talk\Events\BeforeChatMessageSentEvent;
+use OCA\Talk\Events\BeforeCallStartedEvent;
 use OCA\Talk\Events\BeforeDuplicateShareSentEvent;
 use OCA\Talk\Events\BeforeGuestJoinedRoomEvent;
 use OCA\Talk\Events\BeforeParticipantModifiedEvent;
 use OCA\Talk\Events\BeforeRoomDeletedEvent;
 use OCA\Talk\Events\BeforeRoomsFetchEvent;
+use OCA\Talk\Events\BeforeRoomSyncedEvent;
 use OCA\Talk\Events\BeforeSessionLeftRoomEvent;
 use OCA\Talk\Events\BeforeUserJoinedRoomEvent;
+use OCA\Talk\Events\BotDisabledEvent;
+use OCA\Talk\Events\BotEnabledEvent;
 use OCA\Talk\Events\BotInstallEvent;
 use OCA\Talk\Events\BotUninstallEvent;
+use OCA\Talk\Events\CallEndedEvent;
 use OCA\Talk\Events\CallEndedForEveryoneEvent;
 use OCA\Talk\Events\CallNotificationSendEvent;
+use OCA\Talk\Events\CallStartedEvent;
 use OCA\Talk\Events\ChatMessageSentEvent;
 use OCA\Talk\Events\EmailInvitationSentEvent;
 use OCA\Talk\Events\GuestJoinedRoomEvent;
@@ -76,9 +61,13 @@ use OCA\Talk\Events\GuestsCleanedUpEvent;
 use OCA\Talk\Events\LobbyModifiedEvent;
 use OCA\Talk\Events\MessageParseEvent;
 use OCA\Talk\Events\ParticipantModifiedEvent;
+use OCA\Talk\Events\ReactionAddedEvent;
+use OCA\Talk\Events\ReactionRemovedEvent;
 use OCA\Talk\Events\RoomCreatedEvent;
 use OCA\Talk\Events\RoomDeletedEvent;
+use OCA\Talk\Events\RoomExtendedEvent;
 use OCA\Talk\Events\RoomModifiedEvent;
+use OCA\Talk\Events\RoomSyncedEvent;
 use OCA\Talk\Events\SessionLeftRoomEvent;
 use OCA\Talk\Events\SystemMessageSentEvent;
 use OCA\Talk\Events\SystemMessagesMultipleSentEvent;
@@ -88,13 +77,17 @@ use OCA\Talk\Federation\Proxy\TalkV1\Listener\ResourceTypeRegisterListener;
 use OCA\Talk\Federation\Proxy\TalkV1\Notifier\BeforeRoomDeletedListener as TalkV1BeforeRoomDeletedListener;
 use OCA\Talk\Federation\Proxy\TalkV1\Notifier\CancelRetryOCMListener as TalkV1CancelRetryOCMListener;
 use OCA\Talk\Federation\Proxy\TalkV1\Notifier\MessageSentListener as TalkV1MessageSentListener;
+use OCA\Talk\Federation\Proxy\TalkV1\Notifier\ParticipantModifiedListener as TalkV1ParticipantModifiedListener;
 use OCA\Talk\Federation\Proxy\TalkV1\Notifier\RoomModifiedListener as TalkV1RoomModifiedListener;
 use OCA\Talk\Files\Listener as FilesListener;
 use OCA\Talk\Files\TemplateLoader as FilesTemplateLoader;
 use OCA\Talk\Flow\RegisterOperationsListener;
+use OCA\Talk\Listener\AddMissingIndicesListener;
 use OCA\Talk\Listener\BeforeUserLoggedOutListener;
 use OCA\Talk\Listener\BotListener;
+use OCA\Talk\Listener\CalDavEventListener;
 use OCA\Talk\Listener\CircleDeletedListener;
+use OCA\Talk\Listener\CircleEditedListener;
 use OCA\Talk\Listener\CircleMembershipListener;
 use OCA\Talk\Listener\CSPListener;
 use OCA\Talk\Listener\DisplayNameListener;
@@ -103,6 +96,7 @@ use OCA\Talk\Listener\GroupDeletedListener;
 use OCA\Talk\Listener\GroupMembershipListener;
 use OCA\Talk\Listener\NoteToSelfListener;
 use OCA\Talk\Listener\RestrictStartingCalls as RestrictStartingCallsListener;
+use OCA\Talk\Listener\SampleConversationsListener;
 use OCA\Talk\Listener\UserDeletedListener;
 use OCA\Talk\Maps\MapsPluginLoader;
 use OCA\Talk\Middleware\CanUseTalkMiddleware;
@@ -121,7 +115,14 @@ use OCA\Talk\Search\CurrentMessageSearch;
 use OCA\Talk\Search\MessageSearch;
 use OCA\Talk\Search\UnifiedSearchCSSLoader;
 use OCA\Talk\Search\UnifiedSearchFilterPlugin;
+use OCA\Talk\Settings\BeforePreferenceSetEventListener;
 use OCA\Talk\Settings\Personal;
+use OCA\Talk\SetupCheck\BackgroundBlurLoading;
+use OCA\Talk\SetupCheck\Configuration;
+use OCA\Talk\SetupCheck\FederationLockCache;
+use OCA\Talk\SetupCheck\HighPerformanceBackend;
+use OCA\Talk\SetupCheck\RecordingBackend;
+use OCA\Talk\SetupCheck\SIPConfiguration;
 use OCA\Talk\Share\Listener as ShareListener;
 use OCA\Talk\Signaling\Listener as SignalingListener;
 use OCA\Talk\Status\Listener as StatusListener;
@@ -131,9 +132,13 @@ use OCP\AppFramework\App;
 use OCP\AppFramework\Bootstrap\IBootContext;
 use OCP\AppFramework\Bootstrap\IBootstrap;
 use OCP\AppFramework\Bootstrap\IRegistrationContext;
+use OCP\Calendar\Events\CalendarObjectCreatedEvent;
+use OCP\Calendar\Events\CalendarObjectUpdatedEvent;
 use OCP\Collaboration\AutoComplete\AutoCompleteFilterEvent;
 use OCP\Collaboration\Resources\IProviderManager;
 use OCP\Collaboration\Resources\LoadAdditionalScriptsEvent;
+use OCP\Config\BeforePreferenceSetEvent;
+use OCP\DB\Events\AddMissingIndicesEvent;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\Federation\ICloudFederationProvider;
 use OCP\Federation\ICloudFederationProviderManager;
@@ -155,8 +160,8 @@ use OCP\Settings\IManager;
 use OCP\Share\Events\BeforeShareCreatedEvent;
 use OCP\Share\Events\ShareCreatedEvent;
 use OCP\Share\Events\VerifyMountPointEvent;
-use OCP\SpeechToText\Events\TranscriptionFailedEvent;
-use OCP\SpeechToText\Events\TranscriptionSuccessfulEvent;
+use OCP\TaskProcessing\Events\TaskFailedEvent;
+use OCP\TaskProcessing\Events\TaskSuccessfulEvent;
 use OCP\User\Events\BeforeUserLoggedOutEvent;
 use OCP\User\Events\UserChangedEvent;
 use OCP\User\Events\UserDeletedEvent;
@@ -187,24 +192,28 @@ class Application extends App implements IBootstrap {
 		$context->registerEventListener(BeforeTemplateRenderedEvent::class, PublicShareTemplateLoader::class);
 		$context->registerEventListener(BeforeTemplateRenderedEvent::class, PublicShareAuthTemplateLoader::class);
 		$context->registerEventListener(LoadSidebar::class, FilesTemplateLoader::class);
+		$context->registerEventListener(BeforePreferenceSetEvent::class, BeforePreferenceSetEventListener::class);
 
 		// Activity listeners
 		$context->registerEventListener(AttendeesAddedEvent::class, ActivityListener::class);
-		$context->registerEventListener(AttendeeRemovedEvent::class, ActivityListener::class);
-		$context->registerEventListener(BeforeCallEndedForEveryoneEvent::class, ActivityListener::class);
-		$context->registerEventListener(ParticipantModifiedEvent::class, ActivityListener::class, 75);
-		$context->registerEventListener(SessionLeftRoomEvent::class, ActivityListener::class, -100);
+		$context->registerEventListener(CallEndedEvent::class, ActivityListener::class);
+		$context->registerEventListener(CallEndedForEveryoneEvent::class, ActivityListener::class);
 
 		// Bot listeners
+		$context->registerEventListener(BotDisabledEvent::class, BotListener::class);
+		$context->registerEventListener(BotEnabledEvent::class, BotListener::class);
 		$context->registerEventListener(BotInstallEvent::class, BotListener::class);
 		$context->registerEventListener(BotUninstallEvent::class, BotListener::class);
 		$context->registerEventListener(ChatMessageSentEvent::class, BotListener::class);
+		$context->registerEventListener(ReactionAddedEvent::class, BotListener::class);
+		$context->registerEventListener(ReactionRemovedEvent::class, BotListener::class);
 		$context->registerEventListener(SystemMessageSentEvent::class, BotListener::class);
 
 		// Chat listeners
 		$context->registerEventListener(BeforeRoomsFetchEvent::class, ChangelogListener::class);
 		$context->registerEventListener(RoomDeletedEvent::class, ChatListener::class);
 		$context->registerEventListener(BeforeRoomsFetchEvent::class, NoteToSelfListener::class);
+		$context->registerEventListener(BeforeRoomsFetchEvent::class, SampleConversationsListener::class);
 		$context->registerEventListener(AttendeesAddedEvent::class, SystemMessageListener::class);
 		$context->registerEventListener(AttendeeRemovedEvent::class, SystemMessageListener::class);
 		$context->registerEventListener(AttendeesRemovedEvent::class, SystemMessageListener::class);
@@ -219,14 +228,14 @@ class Application extends App implements IBootstrap {
 
 		// Chat parser
 		$context->registerEventListener(MessageParseEvent::class, Changelog::class, -75);
-		$context->registerEventListener(MessageParseEvent::class, Command::class);
 		$context->registerEventListener(MessageParseEvent::class, ReactionParser::class);
 		$context->registerEventListener(MessageParseEvent::class, SystemMessage::class);
 		$context->registerEventListener(MessageParseEvent::class, SystemMessage::class, 9999);
 		$context->registerEventListener(MessageParseEvent::class, UserMention::class, -100);
 
-		// Command listener
-		$context->registerEventListener(BeforeChatMessageSentEvent::class, CommandListener::class);
+		// Calendar listeners
+		$context->registerEventListener(CalendarObjectCreatedEvent::class, CalDavEventListener::class);
+		$context->registerEventListener(CalendarObjectUpdatedEvent::class, CalDavEventListener::class);
 
 		// Files integration listeners
 		$context->registerEventListener(BeforeGuestJoinedRoomEvent::class, FilesListener::class);
@@ -262,12 +271,15 @@ class Application extends App implements IBootstrap {
 		$context->registerEventListener(UserAddedEvent::class, GroupMembershipListener::class);
 		$context->registerEventListener(UserRemovedEvent::class, GroupMembershipListener::class);
 		$context->registerEventListener(CircleDestroyedEvent::class, CircleDeletedListener::class);
+		$context->registerEventListener(EditingCircleEvent::class, CircleEditedListener::class);
+		$context->registerEventListener(CircleEditedEvent::class, CircleEditedListener::class);
 		$context->registerEventListener(AddingCircleMemberEvent::class, CircleMembershipListener::class);
 		$context->registerEventListener(RemovingCircleMemberEvent::class, CircleMembershipListener::class);
 
 		// Notification listeners
 		$context->registerEventListener(AttendeesAddedEvent::class, NotificationListener::class);
-		$context->registerEventListener(BeforeParticipantModifiedEvent::class, NotificationListener::class);
+		$context->registerEventListener(BeforeCallStartedEvent::class, NotificationListener::class);
+		$context->registerEventListener(CallStartedEvent::class, NotificationListener::class);
 		$context->registerEventListener(CallNotificationSendEvent::class, NotificationListener::class);
 		$context->registerEventListener(ParticipantModifiedEvent::class, NotificationListener::class);
 		$context->registerEventListener(UserJoinedRoomEvent::class, NotificationListener::class);
@@ -280,11 +292,17 @@ class Application extends App implements IBootstrap {
 
 		// Recording listeners
 		$context->registerEventListener(RoomDeletedEvent::class, RecordingListener::class);
-		$context->registerEventListener(TranscriptionSuccessfulEvent::class, RecordingListener::class);
-		$context->registerEventListener(TranscriptionFailedEvent::class, RecordingListener::class);
+		$context->registerEventListener(CallEndedEvent::class, RecordingListener::class);
+		$context->registerEventListener(CallEndedForEveryoneEvent::class, RecordingListener::class);
+		$context->registerEventListener(TaskSuccessfulEvent::class, RecordingListener::class);
+		$context->registerEventListener(TaskFailedEvent::class, RecordingListener::class);
 
 		// Federation listeners
 		$context->registerEventListener(BeforeRoomDeletedEvent::class, TalkV1BeforeRoomDeletedListener::class);
+		$context->registerEventListener(ParticipantModifiedEvent::class, TalkV1ParticipantModifiedListener::class);
+		$context->registerEventListener(CallEndedEvent::class, TalkV1RoomModifiedListener::class);
+		$context->registerEventListener(CallEndedForEveryoneEvent::class, TalkV1RoomModifiedListener::class);
+		$context->registerEventListener(CallStartedEvent::class, TalkV1RoomModifiedListener::class);
 		$context->registerEventListener(LobbyModifiedEvent::class, TalkV1RoomModifiedListener::class);
 		$context->registerEventListener(RoomModifiedEvent::class, TalkV1RoomModifiedListener::class);
 		$context->registerEventListener(ChatMessageSentEvent::class, TalkV1MessageSentListener::class);
@@ -302,6 +320,9 @@ class Application extends App implements IBootstrap {
 		$context->registerEventListener(CallEndedForEveryoneEvent::class, SignalingListener::class);
 		$context->registerEventListener(GuestsCleanedUpEvent::class, SignalingListener::class);
 		$context->registerEventListener(LobbyModifiedEvent::class, SignalingListener::class);
+		$context->registerEventListener(BeforeRoomSyncedEvent::class, SignalingListener::class);
+		$context->registerEventListener(RoomSyncedEvent::class, SignalingListener::class);
+		$context->registerEventListener(RoomExtendedEvent::class, SignalingListener::class);
 
 		$context->registerEventListener(ChatMessageSentEvent::class, SignalingListener::class);
 		$context->registerEventListener(SystemMessageSentEvent::class, SignalingListener::class);
@@ -331,6 +352,9 @@ class Application extends App implements IBootstrap {
 		$context->registerSearchProvider(CurrentMessageSearch::class);
 		$context->registerSearchProvider(MessageSearch::class);
 
+		// Fix database issues
+		$context->registerEventListener(AddMissingIndicesEvent::class, AddMissingIndicesListener::class);
+
 		$context->registerDashboardWidget(TalkWidget::class);
 
 		$context->registerNotifierService(Notifier::class);
@@ -342,6 +366,13 @@ class Application extends App implements IBootstrap {
 		$context->registerTalkBackend(TalkBackend::class);
 
 		$context->registerTeamResourceProvider(TalkTeamResourceProvider::class);
+
+		$context->registerSetupCheck(Configuration::class);
+		$context->registerSetupCheck(HighPerformanceBackend::class);
+		$context->registerSetupCheck(FederationLockCache::class);
+		$context->registerSetupCheck(RecordingBackend::class);
+		$context->registerSetupCheck(SIPConfiguration::class);
+		$context->registerSetupCheck(BackgroundBlurLoading::class);
 	}
 
 	public function boot(IBootContext $context): void {
@@ -376,7 +407,7 @@ class Application extends App implements IBootstrap {
 				'name' => $l->t('Talk'),
 				'href' => $urlGenerator->linkToRouteAbsolute('spreed.Page.index'),
 				'icon' => $urlGenerator->imagePath(self::APP_ID, 'app.svg'),
-				'order' => 3,
+				'order' => -5,
 				'type' => $user instanceof IUser && !$config->isDisabledForUser($user) ? 'link' : 'hidden',
 			];
 		});
