@@ -2,24 +2,8 @@
 
 declare(strict_types=1);
 /**
- *
- * @copyright Copyright (c) 2017, Daniel Calviño Sánchez (danxuliu@gmail.com)
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Chat;
@@ -49,6 +33,10 @@ use OCP\Notification\INotification;
  * prepares the notifications for display.
  */
 class Notifier {
+	public const PRIORITY_NONE = 0;
+	public const PRIORITY_NORMAL = 1;
+	public const PRIORITY_IMPORTANT = 2;
+
 	public function __construct(
 		private INotificationManager $notificationManager,
 		private IUserManager $userManager,
@@ -69,13 +57,17 @@ class Notifier {
 	 * Not every user mentioned in the message is notified, but only those that
 	 * are able to participate in the room.
 	 *
+	 * @param Room $chat
+	 * @param IComment $comment
 	 * @param array[] $alreadyNotifiedUsers
 	 * @psalm-param array<int, array{id: string, type: string, reason: string, sourceId?: string, attendee?: Attendee}> $alreadyNotifiedUsers
+	 * @param bool $silent
+	 * @param Participant|null $participant
 	 * @return string[] Users that were mentioned
 	 * @psalm-return array<int, array{id: string, type: string, reason: string, sourceId?: string, attendee?: Attendee}>
 	 */
-	public function notifyMentionedUsers(Room $chat, IComment $comment, array $alreadyNotifiedUsers, bool $silent): array {
-		$usersToNotify = $this->getUsersToNotify($chat, $comment, $alreadyNotifiedUsers);
+	public function notifyMentionedUsers(Room $chat, IComment $comment, array $alreadyNotifiedUsers, bool $silent, ?Participant $participant = null): array {
+		$usersToNotify = $this->getUsersToNotify($chat, $comment, $alreadyNotifiedUsers, $participant);
 
 		if (!$usersToNotify) {
 			return $alreadyNotifiedUsers;
@@ -88,9 +80,9 @@ class Notifier {
 			$shouldFlush = $this->notificationManager->defer();
 		}
 
-
 		foreach ($usersToNotify as $mentionedUser) {
-			if ($this->shouldMentionedUserBeNotified($mentionedUser['id'], $comment, $chat, $mentionedUser['attendee'] ?? null)) {
+			$shouldMentionedUserBeNotified = $this->shouldMentionedUserBeNotified($mentionedUser['id'], $comment, $chat, $mentionedUser['attendee'] ?? null);
+			if ($shouldMentionedUserBeNotified !== self::PRIORITY_NONE) {
 				if (!$silent) {
 					$notification->setUser($mentionedUser['id']);
 					if (isset($mentionedUser['reason'])) {
@@ -100,6 +92,7 @@ class Notifier {
 					} else {
 						$notification->setSubject('mention', $parameters);
 					}
+					$notification->setPriorityNotification($shouldMentionedUserBeNotified === self::PRIORITY_IMPORTANT);
 					$this->notificationManager->notify($notification);
 				}
 				$alreadyNotifiedUsers[] = $mentionedUser;
@@ -118,13 +111,15 @@ class Notifier {
 	 * @param IComment $comment
 	 * @param array $alreadyNotifiedUsers
 	 * @psalm-param array<int, array{id: string, type: string, reason: string, sourceId?: string, attendee?: Attendee}> $alreadyNotifiedUsers
+	 * @param Participant|null $participant
 	 * @return array
 	 * @psalm-return array<int, array{id: string, type: string, reason: string, sourceId?: string, attendee?: Attendee}>
 	 */
-	public function getUsersToNotify(Room $chat, IComment $comment, array $alreadyNotifiedUsers): array {
+	public function getUsersToNotify(Room $chat, IComment $comment, array $alreadyNotifiedUsers, ?Participant $participant = null): array {
 		$usersToNotify = $this->getMentionedUsers($comment);
 		$usersToNotify = $this->getMentionedGroupMembers($chat, $comment, $usersToNotify);
-		$usersToNotify = $this->addMentionAllToList($chat, $usersToNotify);
+		$usersToNotify = $this->getMentionedTeamMembers($chat, $comment, $usersToNotify);
+		$usersToNotify = $this->addMentionAllToList($chat, $usersToNotify, $participant);
 		$usersToNotify = $this->removeAlreadyNotifiedUsers($usersToNotify, $alreadyNotifiedUsers);
 
 		return $usersToNotify;
@@ -153,10 +148,11 @@ class Notifier {
 	 * @param Room $chat
 	 * @param array $list
 	 * @psalm-param array<int, array{id: string, type: string, reason: string, sourceId?: string}> $list
+	 * @param Participant|null $participant
 	 * @return array
 	 * @psalm-return array<int, array{id: string, type: string, reason: string, sourceId?: string, attendee?: Attendee}>
 	 */
-	private function addMentionAllToList(Room $chat, array $list): array {
+	private function addMentionAllToList(Room $chat, array $list, ?Participant $participant = null): array {
 		$usersToNotify = array_filter($list, static function (array $entry): bool {
 			return $entry['type'] !== Attendee::ACTOR_USERS || $entry['id'] !== 'all';
 		});
@@ -164,6 +160,9 @@ class Notifier {
 		if (count($list) === count($usersToNotify)) {
 			return $usersToNotify;
 		}
+		if ($chat->getMentionPermissions() === Room::MENTION_PERMISSIONS_MODERATORS && (!$participant instanceof Participant || !$participant->hasModeratorPermissions())) {
+			return $usersToNotify;
+		}
 
 		$attendees = $this->participantService->getActorsByType($chat, Attendee::ACTOR_USERS);
 		foreach ($attendees as $attendee) {
@@ -192,7 +191,7 @@ class Notifier {
 	 * The comment must be a chat message comment. That is, its "objectId" must
 	 * be the room ID.
 	 *
-	 * The author of the message is notified only if he is still able to participate in the room
+	 * The author of the message is notified only if they are still able to participate in the room
 	 *
 	 * @param Room $chat
 	 * @param IComment $comment
@@ -217,13 +216,15 @@ class Notifier {
 			];
 		}
 
-		if (!$this->shouldMentionedUserBeNotified($replyTo->getActorId(), $comment, $chat)) {
+		$shouldMentionedUserBeNotified = $this->shouldMentionedUserBeNotified($replyTo->getActorId(), $comment, $chat);
+		if ($shouldMentionedUserBeNotified === self::PRIORITY_NONE) {
 			return [];
 		}
 
 		if (!$silent) {
 			$notification = $this->createNotification($chat, $comment, 'reply');
 			$notification->setUser($replyTo->getActorId());
+			$notification->setPriorityNotification($shouldMentionedUserBeNotified === self::PRIORITY_IMPORTANT);
 			$this->notificationManager->notify($notification);
 		}
 
@@ -260,11 +261,13 @@ class Notifier {
 
 		$notification = $this->createNotification($chat, $comment, 'chat');
 		foreach ($participants as $participant) {
-			if (!$this->shouldParticipantBeNotified($participant, $comment, $alreadyNotifiedUsers)) {
+			$shouldParticipantBeNotified = $this->shouldParticipantBeNotified($participant, $comment, $alreadyNotifiedUsers);
+			if ($shouldParticipantBeNotified === self::PRIORITY_NONE) {
 				continue;
 			}
 
 			$notification->setUser($participant->getAttendee()->getActorId());
+			$notification->setPriorityNotification($shouldParticipantBeNotified === self::PRIORITY_IMPORTANT);
 			$this->notificationManager->notify($notification);
 		}
 
@@ -272,11 +275,13 @@ class Notifier {
 		if ($this->getDefaultGroupNotification() === Participant::NOTIFY_ALWAYS || $chat->getType() === Room::TYPE_ONE_TO_ONE) {
 			$participants = $this->participantService->getParticipantsByNotificationLevel($chat, Participant::NOTIFY_DEFAULT);
 			foreach ($participants as $participant) {
-				if (!$this->shouldParticipantBeNotified($participant, $comment, $alreadyNotifiedUsers)) {
+				$shouldParticipantBeNotified = $this->shouldParticipantBeNotified($participant, $comment, $alreadyNotifiedUsers);
+				if ($shouldParticipantBeNotified === self::PRIORITY_NONE) {
 					continue;
 				}
 
 				$notification->setUser($participant->getAttendee()->getActorId());
+				$notification->setPriorityNotification($shouldParticipantBeNotified === self::PRIORITY_IMPORTANT);
 				$this->notificationManager->notify($notification);
 			}
 		}
@@ -540,6 +545,57 @@ class Notifier {
 		return $list;
 	}
 
+	/**
+	 * @param Room $chat
+	 * @param IComment $comment
+	 * @param array $list
+	 * @psalm-param array<int, array{type: string, id: string, reason: string, sourceId?: string}> $list
+	 * @return array[]
+	 * @psalm-return array<int, array{type: string, id: string, reason: string, sourceId?: string}>
+	 */
+	private function getMentionedTeamMembers(Room $chat, IComment $comment, array $list): array {
+		$mentions = $comment->getMentions();
+
+		if (empty($mentions)) {
+			return [];
+		}
+
+		$alreadyMentionedUserIds = array_filter(
+			array_map(static fn (array $entry) => $entry['type'] === Attendee::ACTOR_USERS ? $entry['id'] : null, $list),
+			static fn ($userId) => $userId !== null
+		);
+		$alreadyMentionedUserIds = array_flip($alreadyMentionedUserIds);
+
+		foreach ($mentions as $mention) {
+			if ($mention['type'] !== 'team') {
+				continue;
+			}
+
+			try {
+				$this->participantService->getParticipantByActor($chat, Attendee::ACTOR_CIRCLES, $mention['id']);
+			} catch (ParticipantNotFoundException) {
+				continue;
+			}
+
+			$members = $this->participantService->getCircleMembers($mention['id']);
+			if (empty($members)) {
+				continue;
+			}
+
+			foreach ($members as $member) {
+				$list[] = [
+					'id' => $member->getUserId(),
+					'type' => Attendee::ACTOR_USERS,
+					'reason' => 'team',
+					'sourceId' => $mention['id'],
+				];
+				$alreadyMentionedUserIds[$member->getUserId()] = true;
+			}
+		}
+
+		return $list;
+	}
+
 	/**
 	 * Creates a notification for the given chat message comment and mentioned
 	 * user ID.
@@ -562,7 +618,7 @@ class Notifier {
 	}
 
 	protected function getDefaultGroupNotification(): int {
-		return (int) $this->config->getAppValue('spreed', 'default_group_notification', (string) Participant::NOTIFY_MENTION);
+		return (int)$this->config->getAppValue('spreed', 'default_group_notification', (string)Participant::NOTIFY_MENTION);
 	}
 
 	/**
@@ -572,23 +628,17 @@ class Notifier {
 	 * 2. The user must exist
 	 * 3. The user must be a participant of the room
 	 * 4. The user must not be active in the room
-	 *
-	 * @param string $userId
-	 * @param IComment $comment
-	 * @param Room $room
-	 * @param Attendee|null $attendee
-	 * @return bool
 	 */
-	protected function shouldMentionedUserBeNotified(string $userId, IComment $comment, Room $room, ?Attendee $attendee = null): bool {
+	protected function shouldMentionedUserBeNotified(string $userId, IComment $comment, Room $room, ?Attendee $attendee = null): int {
 		if ($comment->getActorType() === Attendee::ACTOR_USERS && $userId === $comment->getActorId()) {
 			// Do not notify the user if they mentioned themselves
-			return false;
+			return self::PRIORITY_NONE;
 		}
 
 		try {
 			if (!$attendee instanceof Attendee) {
 				if (!$this->userManager->userExists($userId)) {
-					return false;
+					return self::PRIORITY_NONE;
 				}
 
 				$participant = $this->participantService->getParticipant($room, $userId, false);
@@ -599,7 +649,7 @@ class Notifier {
 
 			if ($room->getLobbyState() !== Webinary::LOBBY_NONE &&
 				!($participant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
-				return false;
+				return self::PRIORITY_NONE;
 			}
 
 			$notificationLevel = $attendee->getNotificationLevel();
@@ -610,7 +660,14 @@ class Notifier {
 					$notificationLevel = $this->getDefaultGroupNotification();
 				}
 			}
-			return $notificationLevel !== Participant::NOTIFY_NEVER;
+			if ($notificationLevel === Participant::NOTIFY_NEVER) {
+				return self::PRIORITY_NONE;
+			}
+
+			if ($attendee->isImportant()) {
+				return self::PRIORITY_IMPORTANT;
+			}
+			return self::PRIORITY_NORMAL;
 		} catch (ParticipantNotFoundException $e) {
 			if ($room->getObjectType() === 'file' && $this->util->canUserAccessFile($room->getObjectId(), $userId)) {
 				// Users are added on mentions in file-rooms,
@@ -623,9 +680,9 @@ class Notifier {
 					'actorId' => $userId,
 					'displayName' => $userDisplayName ?? $userId,
 				]]);
-				return true;
+				return self::PRIORITY_NORMAL;
 			}
-			return false;
+			return self::PRIORITY_NONE;
 		}
 	}
 
@@ -637,35 +694,35 @@ class Notifier {
 	 * 3. The participant was not mentioned already
 	 * 4. The participant must not be active in the room
 	 *
-	 * @param Participant $participant
-	 * @param IComment $comment
-	 * @param array $alreadyNotifiedUsers
 	 * @psalm-param array<int, array{type: string, id: string, reason: string, sourceId?: string, attendee?: Attendee}> $alreadyNotifiedUsers
-	 * @return bool
 	 */
-	protected function shouldParticipantBeNotified(Participant $participant, IComment $comment, array $alreadyNotifiedUsers): bool {
+	protected function shouldParticipantBeNotified(Participant $participant, IComment $comment, array $alreadyNotifiedUsers): int {
 		if ($participant->getAttendee()->getActorType() !== Attendee::ACTOR_USERS) {
-			return false;
+			return self::PRIORITY_NONE;
 		}
 
 		$userId = $participant->getAttendee()->getActorId();
 		if ($comment->getActorType() === Attendee::ACTOR_USERS && $userId === $comment->getActorId()) {
 			// Do not notify the author
-			return false;
+			return self::PRIORITY_NONE;
 		}
 
 		$actorType = $participant->getAttendee()->getActorType();
 		foreach ($alreadyNotifiedUsers as $user) {
 			if ($user['id'] === $userId && $user['type'] === $actorType) {
-				return false;
+				return self::PRIORITY_NONE;
 			}
 		}
 
-		if ($participant->getSession() instanceof Session) {
+		if ($participant->getSession()?->getLastPing() >= $this->timeFactory->getTime() - Session::SESSION_TIMEOUT) {
 			// User is online
-			return $participant->getSession()->getLastPing() < $this->timeFactory->getTime() - Session::SESSION_TIMEOUT;
+			return self::PRIORITY_NONE;
 		}
 
-		return true;
+		if ($participant->getAttendee()->isImportant()) {
+			return self::PRIORITY_IMPORTANT;
+		}
+
+		return self::PRIORITY_NORMAL;
 	}
 }
