@@ -12,6 +12,7 @@ use OCA\Circles\CirclesManager;
 use OCA\DAV\CardDAV\PhotoCache;
 use OCA\Talk\Chat\ChatManager;
 use OCA\Talk\Events\MessageParseEvent;
+use OCA\Talk\Events\OverwritePublicSharePropertiesEvent;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Federation\Authenticator;
 use OCA\Talk\GuestManager;
@@ -22,11 +23,14 @@ use OCA\Talk\Room;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Share\Helper\FilesMetadataCache;
 use OCA\Talk\Share\RoomShareProvider;
+use OCP\AppFramework\Services\IAppConfig;
 use OCP\Comments\IComment;
 use OCP\Comments\ICommentsManager;
 use OCP\EventDispatcher\Event;
+use OCP\EventDispatcher\IEventDispatcher;
 use OCP\EventDispatcher\IEventListener;
 use OCP\Federation\ICloudIdManager;
+use OCP\Files\FileInfo;
 use OCP\Files\InvalidPathException;
 use OCP\Files\IRootFolder;
 use OCP\Files\Node;
@@ -67,6 +71,7 @@ class SystemMessage implements IEventListener {
 	protected array $currentFederatedUserDetails = [];
 
 	public function __construct(
+		protected IAppConfig $appConfig,
 		protected IUserManager $userManager,
 		protected IGroupManager $groupManager,
 		protected GuestManager $guestManager,
@@ -79,6 +84,7 @@ class SystemMessage implements IEventListener {
 		protected IURLGenerator $url,
 		protected FilesMetadataCache $metadataCache,
 		protected Authenticator $federationAuthenticator,
+		protected IEventDispatcher $dispatcher,
 	) {
 	}
 
@@ -89,7 +95,7 @@ class SystemMessage implements IEventListener {
 
 		if ($event->getMessage()->getMessageType() === ChatManager::VERB_SYSTEM) {
 			try {
-				$this->parseMessage($event->getMessage());
+				$this->parseMessage($event->getMessage(), $event->allowInaccurate());
 				// Disabled so we can parse mentions in captions: $event->stopPropagation();
 			} catch (\OutOfBoundsException $e) {
 				// Unknown message, ignore
@@ -108,7 +114,7 @@ class SystemMessage implements IEventListener {
 	 * @param Message $chatMessage
 	 * @throws \OutOfBoundsException
 	 */
-	protected function parseMessage(Message $chatMessage): void {
+	protected function parseMessage(Message $chatMessage, $allowInaccurate): void {
 		$this->l = $chatMessage->getL10n();
 		$comment = $chatMessage->getComment();
 		$room = $chatMessage->getRoom();
@@ -203,14 +209,26 @@ class SystemMessage implements IEventListener {
 			if ($silentCall) {
 				if ($currentUserIsActor) {
 					$parsedMessage = $this->l->t('You started a silent call');
+					if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
+						$parsedMessage = $this->l->t('Outgoing silent call');
+					}
 				} else {
 					$parsedMessage = $this->l->t('{actor} started a silent call');
+					if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
+						$parsedMessage = $this->l->t('Incoming silent call');
+					}
 				}
 			} else {
 				if ($currentUserIsActor) {
 					$parsedMessage = $this->l->t('You started a call');
+					if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
+						$parsedMessage = $this->l->t('Outgoing call');
+					}
 				} else {
 					$parsedMessage = $this->l->t('{actor} started a call');
+					if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
+						$parsedMessage = $this->l->t('Incoming call');
+					}
 				}
 			}
 		} elseif ($message === 'call_joined') {
@@ -500,7 +518,7 @@ class SystemMessage implements IEventListener {
 			}
 		} elseif ($message === 'file_shared') {
 			try {
-				$parsedParameters['file'] = $this->getFileFromShare($room, $participant, $parameters['share']);
+				$parsedParameters['file'] = $this->getFileFromShare($room, $participant, $parameters['share'], $allowInaccurate);
 				$parsedMessage = '{file}';
 				$metaData = $parameters['metaData'] ?? [];
 				if (isset($metaData['messageType'])) {
@@ -744,18 +762,24 @@ class SystemMessage implements IEventListener {
 	}
 
 	/**
-	 * @param ?Participant $participant
-	 * @param string $shareId
-	 * @return array
 	 * @throws InvalidPathException
 	 * @throws NotFoundException
 	 * @throws ShareNotFound
 	 */
-	protected function getFileFromShare(Room $room, ?Participant $participant, string $shareId): array {
+	protected function getFileFromShare(Room $room, ?Participant $participant, string $shareId, bool $allowInaccurate): array {
 		$share = $this->shareProvider->getShareById((int)$shareId);
 
 		if ($participant && $participant->getAttendee()->getActorType() === Attendee::ACTOR_USERS) {
-			if ($share->getShareOwner() !== $participant->getAttendee()->getActorId()) {
+			if ($allowInaccurate) {
+				$node = $share->getNodeCacheEntry();
+				if ($node === null) {
+					throw new ShareNotFound();
+				}
+
+				$name = $node->getName();
+				$size = $node->getSize();
+				$path = $name;
+			} elseif ($share->getShareOwner() !== $participant->getAttendee()->getActorId()) {
 				$userFolder = $this->rootFolder->getUserFolder($participant->getAttendee()->getActorId());
 				if (!$userFolder instanceof Node) {
 					throw new ShareNotFound();
@@ -799,7 +823,13 @@ class SystemMessage implements IEventListener {
 		} elseif ($participant && $room->getType() !== Room::TYPE_PUBLIC && $participant->getAttendee()->getActorType() === Attendee::ACTOR_FEDERATED_USERS) {
 			throw new ShareNotFound();
 		} else {
-			$node = $share->getNode();
+			if ($allowInaccurate) {
+				$node = $share->getNodeCacheEntry();
+			} else {
+				$node = $share->getNode();
+				$this->dispatcher->dispatchTyped(new OverwritePublicSharePropertiesEvent($share));
+			}
+
 			$name = $node->getName();
 			$size = $node->getSize();
 			$path = $name;
@@ -810,7 +840,11 @@ class SystemMessage implements IEventListener {
 		}
 
 		$fileId = $node->getId();
-		$isPreviewAvailable = $this->previewManager->isAvailable($node);
+		if ($node instanceof FileInfo) {
+			$isPreviewAvailable = $this->previewManager->isAvailable($node);
+		} else {
+			$isPreviewAvailable = $size > 0 && $this->previewManager->isMimeSupported($node->getMimeType());
+		}
 
 		$data = [
 			'type' => 'file',
@@ -823,6 +857,7 @@ class SystemMessage implements IEventListener {
 			'permissions' => (string)$node->getPermissions(),
 			'mimetype' => $node->getMimeType(),
 			'preview-available' => $isPreviewAvailable ? 'yes' : 'no',
+			'hide-download' => $share->getHideDownload() ? 'yes' : 'no',
 		];
 
 		// If a preview is available, check if we can get the dimensions of the file from the metadata API
@@ -841,7 +876,7 @@ class SystemMessage implements IEventListener {
 			}
 		}
 
-		if ($node->getMimeType() === 'text/vcard') {
+		if ($node instanceof FileInfo && $node->getMimeType() === 'text/vcard') {
 			$vCard = $node->getContent();
 
 			$vObject = Reader::read($vCard);
@@ -922,6 +957,7 @@ class SystemMessage implements IEventListener {
 			'type' => 'user',
 			'id' => $uid,
 			'name' => $this->displayNames[$uid],
+			'mention-id' => $uid,
 		];
 	}
 
@@ -939,6 +975,7 @@ class SystemMessage implements IEventListener {
 			'id' => $cloudId->getUser(),
 			'name' => $displayName,
 			'server' => $cloudId->getRemote(),
+			'mention-id' => 'federated_user/' . $cloudId->getUser() . '@' . $cloudId->getRemote(),
 		];
 	}
 
@@ -960,6 +997,7 @@ class SystemMessage implements IEventListener {
 			'type' => 'group',
 			'id' => $gid,
 			'name' => $this->groupNames[$gid],
+			'mention-id' => 'user-group/' . $gid,
 		];
 	}
 
@@ -993,6 +1031,7 @@ class SystemMessage implements IEventListener {
 			'id' => $circleId,
 			'name' => $this->circleNames[$circleId],
 			'link' => $this->circleLinks[$circleId],
+			'mention-id' => 'team/' . $circleId,
 		];
 	}
 
@@ -1040,11 +1079,22 @@ class SystemMessage implements IEventListener {
 			'type' => 'guest',
 			'id' => ($actorType === Attendee::ACTOR_GUESTS ? 'guest/' : 'email/') . $actorId,
 			'name' => $this->guestNames[$key],
+			'mention-id' => ($actorType === Attendee::ACTOR_GUESTS ? 'guest/' : 'email/') . $actorId,
 		];
 	}
 
 	protected function getGuestName(Room $room, string $actorType, string $actorId): string {
 		if ($actorId === Attendee::ACTOR_ID_CLI) {
+			// TRANSLATORS Actor name when a chat message was done by an administration person via the commmand line
+			return $this->l->t('Administration');
+		}
+		if ($actorId === Attendee::ACTOR_ID_SYSTEM) {
+			// TRANSLATORS Actor name when a chat message was done by the system instead of an actual actor
+			return $this->l->t('System');
+		}
+		if ($actorId === Attendee::ACTOR_ID_SAMPLE
+			|| $actorId === Attendee::ACTOR_ID_CHANGELOG) {
+			// Will be set by the Changelog Parser
 			return $this->l->t('Guest');
 		}
 
@@ -1065,7 +1115,7 @@ class SystemMessage implements IEventListener {
 	protected function parseMissedCall(Room $room, array $parameters, ?string $currentActorId): array {
 		if ($parameters['users'][0] !== $currentActorId) {
 			return [
-				$this->l->t('You missed a call from {user}'),
+				$this->l->t('Missed call'),
 				[
 					'user' => $this->getUser($parameters['users'][0]),
 				],
@@ -1076,7 +1126,7 @@ class SystemMessage implements IEventListener {
 		if ($room->getType() !== Room::TYPE_ONE_TO_ONE) {
 			// Can happen if a user was remove from a one-to-one room.
 			return [
-				$this->l->t('You tried to call {user}'),
+				$this->l->t('Unanswered call'),
 				[
 					'user' => [
 						'type' => 'highlight',
@@ -1097,7 +1147,7 @@ class SystemMessage implements IEventListener {
 		}
 
 		return [
-			$this->l->t('You tried to call {user}'),
+			$this->l->t('Unanswered call'),
 			[
 				'user' => $this->getUser($other),
 			],
@@ -1108,6 +1158,18 @@ class SystemMessage implements IEventListener {
 
 	protected function parseCall(Room $room, string $message, array $parameters, array $params): array {
 		$actorIsSystem = $params['actor']['type'] === 'guest' && $params['actor']['id'] === 'guest/' . Attendee::ACTOR_ID_SYSTEM;
+		$maxDuration = $this->appConfig->getAppValueInt('max_call_duration');
+		$maxDurationWasReached = $message === 'call_ended_everyone' && $actorIsSystem && $maxDuration > 0 && $parameters['duration'] > $maxDuration;
+
+		if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
+			$subject = $this->l->t('Call ended (Duration {duration})');
+			$subject = str_replace('{duration}', $this->getDuration($parameters['duration']), $subject);
+			return [
+				$subject,
+				$params,
+			];
+		}
+
 		if ($message === 'call_ended_everyone') {
 			if ($params['actor']['type'] === 'user') {
 				$entry = array_keys($parameters['users'], $params['actor']['id'], true);
@@ -1133,7 +1195,7 @@ class SystemMessage implements IEventListener {
 			case 0:
 				if ($parameters['guests'] === 0) {
 					// Call without users and guests
-					if ($actorIsSystem) {
+					if ($maxDurationWasReached) {
 						$subject = $this->l->t('Call was ended, as it reached the maximum call duration (Duration {duration})');
 					} elseif ($message === 'call_ended') {
 						$subject = $this->l->t('Call ended (Duration {duration})');
@@ -1141,7 +1203,7 @@ class SystemMessage implements IEventListener {
 						$subject = $this->l->t('{actor} ended the call (Duration {duration})');
 					}
 				} else {
-					if ($actorIsSystem) {
+					if ($maxDurationWasReached) {
 						$subject = $this->l->n(
 							'Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})',
 							'Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})',
@@ -1164,7 +1226,7 @@ class SystemMessage implements IEventListener {
 				break;
 			case 1:
 				if ($parameters['guests'] === 0) {
-					if ($actorIsSystem) {
+					if ($maxDurationWasReached) {
 						$subject = $this->l->t('Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})');
 					} elseif ($message === 'call_ended') {
 						$subject = $this->l->t('Call with {user1} ended (Duration {duration})');
@@ -1172,7 +1234,7 @@ class SystemMessage implements IEventListener {
 						$subject = $this->l->t('{actor} ended the call with {user1} (Duration {duration})');
 					}
 				} else {
-					if ($actorIsSystem) {
+					if ($maxDurationWasReached) {
 						$subject = $this->l->t('Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})');
 					} elseif ($message === 'call_ended') {
 						$subject = $this->l->t('Call with {user1} and {user2} ended (Duration {duration})');
@@ -1184,7 +1246,7 @@ class SystemMessage implements IEventListener {
 				break;
 			case 2:
 				if ($parameters['guests'] === 0) {
-					if ($actorIsSystem) {
+					if ($maxDurationWasReached) {
 						$subject = $this->l->t('Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})');
 					} elseif ($message === 'call_ended') {
 						$subject = $this->l->t('Call with {user1} and {user2} ended (Duration {duration})');
@@ -1192,7 +1254,7 @@ class SystemMessage implements IEventListener {
 						$subject = $this->l->t('{actor} ended the call with {user1} and {user2} (Duration {duration})');
 					}
 				} else {
-					if ($actorIsSystem) {
+					if ($maxDurationWasReached) {
 						$subject = $this->l->t('Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})');
 					} elseif ($message === 'call_ended') {
 						$subject = $this->l->t('Call with {user1}, {user2} and {user3} ended (Duration {duration})');
@@ -1204,7 +1266,7 @@ class SystemMessage implements IEventListener {
 				break;
 			case 3:
 				if ($parameters['guests'] === 0) {
-					if ($actorIsSystem) {
+					if ($maxDurationWasReached) {
 						$subject = $this->l->t('Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})');
 					} elseif ($message === 'call_ended') {
 						$subject = $this->l->t('Call with {user1}, {user2} and {user3} ended (Duration {duration})');
@@ -1212,7 +1274,7 @@ class SystemMessage implements IEventListener {
 						$subject = $this->l->t('{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})');
 					}
 				} else {
-					if ($actorIsSystem) {
+					if ($maxDurationWasReached) {
 						$subject = $this->l->t('Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})');
 					} elseif ($message === 'call_ended') {
 						$subject = $this->l->t('Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})');
@@ -1224,7 +1286,7 @@ class SystemMessage implements IEventListener {
 				break;
 			case 4:
 				if ($parameters['guests'] === 0) {
-					if ($actorIsSystem) {
+					if ($maxDurationWasReached) {
 						$subject = $this->l->t('Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})');
 					} elseif ($message === 'call_ended') {
 						$subject = $this->l->t('Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})');
@@ -1232,7 +1294,7 @@ class SystemMessage implements IEventListener {
 						$subject = $this->l->t('{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})');
 					}
 				} else {
-					if ($actorIsSystem) {
+					if ($maxDurationWasReached) {
 						$subject = $this->l->t('Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})');
 					} elseif ($message === 'call_ended') {
 						$subject = $this->l->t('Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})');
@@ -1244,7 +1306,7 @@ class SystemMessage implements IEventListener {
 				break;
 			case 5:
 			default:
-				if ($actorIsSystem) {
+				if ($maxDurationWasReached) {
 					$subject = $this->l->t('Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})');
 				} elseif ($message === 'call_ended') {
 					$subject = $this->l->t('Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})');
