@@ -2,26 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2023 Joas Schilling <coding@schilljs.com>
- *
- * @author Joas Schilling <coding@schilljs.com>
- * @author Kate Döen <kate.doeen@nextcloud.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2023 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 namespace OCA\Talk\Service;
 
@@ -38,6 +20,7 @@ use OCA\Talk\Room;
 use OCA\Talk\Webinary;
 use OCP\App\IAppManager;
 use OCP\AppFramework\Db\DoesNotExistException;
+use OCP\AppFramework\Services\IAppConfig;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\IComment;
 use OCP\IConfig;
@@ -54,6 +37,7 @@ use OCP\UserStatus\IUserStatus;
 class RoomFormatter {
 	public function __construct(
 		protected Config $talkConfig,
+		protected IAppConfig $appConfig,
 		protected AvatarService $avatarService,
 		protected ParticipantService $participantService,
 		protected ChatManager $chatManager,
@@ -81,6 +65,7 @@ class RoomFormatter {
 		?array $statuses = null,
 		bool $isSIPBridgeRequest = false,
 		bool $isListingBreakoutRooms = false,
+		bool $skipLastMessage = false,
 	): array {
 		return $this->formatRoomV4(
 			$responseFormat,
@@ -90,6 +75,7 @@ class RoomFormatter {
 			$statuses,
 			$isSIPBridgeRequest,
 			$isListingBreakoutRooms,
+			$skipLastMessage,
 		);
 	}
 
@@ -105,6 +91,7 @@ class RoomFormatter {
 		?array $statuses,
 		bool $isSIPBridgeRequest,
 		bool $isListingBreakoutRooms,
+		bool $skipLastMessage,
 	): array {
 		$roomData = [
 			'id' => $room->getId(),
@@ -136,7 +123,6 @@ class RoomFormatter {
 			'lobbyTimer' => 0,
 			'lastPing' => 0,
 			'sessionId' => '0',
-			'lastMessage' => [],
 			'sipEnabled' => Webinary::SIP_DISABLED,
 			'actorType' => '',
 			'actorId' => '',
@@ -157,8 +143,16 @@ class RoomFormatter {
 			'breakoutRoomMode' => BreakoutRoom::MODE_NOT_CONFIGURED,
 			'breakoutRoomStatus' => BreakoutRoom::STATUS_STOPPED,
 			'recordingConsent' => $this->talkConfig->recordingConsentRequired() === RecordingService::CONSENT_REQUIRED_OPTIONAL ? $room->getRecordingConsent() : $this->talkConfig->recordingConsentRequired(),
+			'mentionPermissions' => Room::MENTION_PERMISSIONS_EVERYONE,
+			'isArchived' => false,
+			'isImportant' => false,
+			'isSensitive' => false,
 		];
 
+		if ($room->isFederatedConversation()) {
+			$roomData['recordingConsent'] = $room->getRecordingConsent();
+		}
+
 		$lastActivity = $room->getLastActivity();
 		if ($lastActivity instanceof \DateTimeInterface) {
 			$lastActivity = $lastActivity->getTimestamp();
@@ -180,6 +174,7 @@ class RoomFormatter {
 			return array_merge($roomData, [
 				'name' => $room->getName(),
 				'displayName' => $room->getDisplayName($isListingBreakoutRooms || $isSIPBridgeRequest || $this->userId === null ? '' : $this->userId, $isListingBreakoutRooms || $isSIPBridgeRequest),
+				'description' => $room->getListable() !== Room::LISTABLE_NONE ? $room->getDescription() : '',
 				'objectType' => $room->getObjectType(),
 				'objectId' => $room->getObjectId(),
 				'readOnly' => $room->getReadOnly(),
@@ -227,15 +222,23 @@ class RoomFormatter {
 			'attendeeId' => $attendee->getId(),
 			'permissions' => $currentParticipant->getPermissions(),
 			'attendeePermissions' => $attendee->getPermissions(),
-			'callPermissions' => $room->getCallPermissions(),
+			'callPermissions' => Attendee::PERMISSIONS_DEFAULT,
 			'defaultPermissions' => $room->getDefaultPermissions(),
 			'description' => $room->getDescription(),
 			'listable' => $room->getListable(),
 			'messageExpiration' => $room->getMessageExpiration(),
 			'breakoutRoomMode' => $room->getBreakoutRoomMode(),
 			'breakoutRoomStatus' => $room->getBreakoutRoomStatus(),
+			'mentionPermissions' => $room->getMentionPermissions(),
+			'isArchived' => $attendee->isArchived(),
+			'isImportant' => $attendee->isImportant(),
+			'isSensitive' => $attendee->isSensitive(),
 		]);
 
+		if ($room->isFederatedConversation()) {
+			$roomData['recordingConsent'] = $room->getRecordingConsent();
+		}
+
 		if ($currentParticipant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
 			if (isset($commonReadMessages[$room->getId()])) {
 				$roomData['lastCommonReadMessage'] = $commonReadMessages[$room->getId()];
@@ -278,17 +281,7 @@ class RoomFormatter {
 			}
 		}
 
-		if ($room->getLobbyState() === Webinary::LOBBY_NON_MODERATORS &&
-			!$currentParticipant->hasModeratorPermissions() &&
-			!($currentParticipant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
-			// No participants and chat messages for users in the lobby.
-			$roomData['hasCall'] = false;
-			$roomData['canLeaveConversation'] = true;
-			return $roomData;
-		}
-
-		$roomData['canStartCall'] = $currentParticipant->canStartCall($this->serverConfig);
-
+		$currentUser = null;
 		if ($attendee->getActorType() === Attendee::ACTOR_USERS) {
 			$currentUser = $this->userManager->get($attendee->getActorId());
 			if ($room->isFederatedConversation()) {
@@ -298,7 +291,7 @@ class RoomFormatter {
 				$roomData['unreadMessages'] = $attendee->getUnreadMessages();
 			} elseif ($currentUser instanceof IUser) {
 				$lastReadMessage = $attendee->getLastReadMessage();
-				if ($lastReadMessage === -1) {
+				if ($lastReadMessage === ChatManager::UNREAD_MIGRATION) {
 					/*
 					 * Because the migration from the old comment_read_markers was
 					 * not possible in a programmatic way with a reasonable O(1) or O(n)
@@ -325,6 +318,13 @@ class RoomFormatter {
 					&& $room->getType() !== Room::TYPE_ONE_TO_ONE_FORMER
 					&& $currentParticipant->hasModeratorPermissions(false);
 				$roomData['canLeaveConversation'] = $room->getType() !== Room::TYPE_NOTE_TO_SELF;
+
+				if ($this->appConfig->getAppValueBool('delete_one_to_one_conversations')
+					&& in_array($room->getType(), [Room::TYPE_ONE_TO_ONE, Room::TYPE_ONE_TO_ONE_FORMER], true)) {
+					$roomData['canDeleteConversation'] = true;
+					$roomData['canLeaveConversation'] = false;
+				}
+
 				$roomData['canEnableSIP'] =
 					$this->talkConfig->isSIPConfigured()
 					&& !preg_match(Room::SIP_INCOMPATIBLE_REGEX, $room->getToken())
@@ -341,6 +341,9 @@ class RoomFormatter {
 			$roomData['unreadMention'] = $lastMention !== 0 && $lastReadMessage < $lastMention;
 			$roomData['unreadMentionDirect'] = $lastMentionDirect !== 0 && $lastReadMessage < $lastMentionDirect;
 		} else {
+			if ($attendee->getActorType() === Attendee::ACTOR_EMAILS) {
+				$roomData['invitedActorId'] = $attendee->getInvitedCloudId();
+			}
 			$roomData['lastReadMessage'] = $attendee->getLastReadMessage();
 		}
 
@@ -349,6 +352,19 @@ class RoomFormatter {
 			$roomData['remoteToken'] = $room->getRemoteToken();
 		}
 
+		if ($room->getLobbyState() === Webinary::LOBBY_NON_MODERATORS &&
+			!$currentParticipant->hasModeratorPermissions() &&
+			!($currentParticipant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
+			// No participants and chat messages for users in the lobby.
+			$roomData['hasCall'] = false;
+			$roomData['unreadMessages'] = 0;
+			$roomData['unreadMention'] = false;
+			$roomData['unreadMentionDirect'] = false;
+			return $roomData;
+		}
+
+		$roomData['canStartCall'] = $currentParticipant->canStartCall($this->serverConfig);
+
 		// FIXME This should not be done, but currently all the clients use it to get the avatar of the user …
 		if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
 			$participants = json_decode($room->getName(), true);
@@ -377,15 +393,18 @@ class RoomFormatter {
 			}
 		}
 
-		$roomData['lastMessage'] = [];
-		$lastMessage = $room->getLastMessage();
+		$skipLastMessage = $skipLastMessage || $attendee->isSensitive();
+		$lastMessage = $skipLastMessage ? null : $room->getLastMessage();
 		if (!$room->isFederatedConversation() && $lastMessage instanceof IComment) {
-			$roomData['lastMessage'] = $this->formatLastMessage(
+			$lastMessageData = $this->formatLastMessage(
 				$responseFormat,
 				$room,
 				$currentParticipant,
 				$lastMessage,
 			);
+			if ($lastMessageData !== null) {
+				$roomData['lastMessage'] = $lastMessageData;
+			}
 		} elseif ($room->isFederatedConversation()) {
 			$roomData['lastCommonReadMessage'] = 0;
 			try {
@@ -399,8 +418,20 @@ class RoomFormatter {
 			}
 		}
 
+		if ($roomData['lastReadMessage'] === 0) {
+			// Guest in a fully expired chat, no history, just loading the chat from beginning for now
+			$roomData['lastReadMessage'] = ChatManager::UNREAD_FIRST_MESSAGE;
+		}
+
+		if ($currentUser instanceof IUser
+			&& $attendee->getActorType() === Attendee::ACTOR_USERS
+			&& $roomData['lastReadMessage'] === ChatManager::UNREAD_FIRST_MESSAGE
+			&& $roomData['unreadMessages'] === 0) {
+			$roomData['unreadMessages'] = 1;
+		}
+
 		if ($room->isFederatedConversation()) {
-			$roomData['attendeeId'] = (int) $attendee->getRemoteId();
+			$roomData['attendeeId'] = (int)$attendee->getRemoteId();
 			$roomData['canLeaveConversation'] = true;
 		}
 
@@ -408,25 +439,25 @@ class RoomFormatter {
 	}
 
 	/**
-	 * @return TalkRoomLastMessage|array<empty>
+	 * @return TalkRoomLastMessage|null
 	 */
 	public function formatLastMessage(
 		string $responseFormat,
 		Room $room,
 		Participant $participant,
 		IComment $lastMessage,
-	): array {
+	): ?array {
 		$message = $this->messageParser->createMessage($room, $participant, $lastMessage, $this->l10n);
-		$this->messageParser->parseMessage($message);
+		$this->messageParser->parseMessage($message, true);
 
 		if (!$message->getVisibility()) {
-			return [];
+			return null;
 		}
 
 		$now = $this->timeFactory->getDateTime();
 		$expireDate = $message->getComment()->getExpireDate();
 		if ($expireDate instanceof \DateTime && $expireDate < $now) {
-			return [];
+			return null;
 		}
 
 		return $message->toArray($responseFormat);
